from floraconcierge.client.types import Object


class Count(Object):
    """
    :type id: int
    """

    def __init__(self, *args, **kwargs):
        self.count = None
        self.id = None
        self.inflect1 = None
        self.inflect2 = None
        self.inflect3 = None
        self.inflect4 = None
        self.inflect5 = None
        self.inflect6 = None
        self.word = None

        super(Count, self).__init__(*args, **kwargs)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('apiauth', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='user',
            name='email',
            field=models.EmailField(unique=True, max_length=254),
        ),
        migrations.AlterField(
            model_name='user',
            name='groups',
            field=models.ManyToManyField(related_query_name='user', related_name='user_set', to='auth.Group', blank=True, help_text='The groups this user belongs to. A user will get all permissions granted to each of their groups.', verbose_name='groups'),
        ),
    ]



from floraconcierge.shortcuts import get_apiclient


def clients(partner_id=None, from_datetime=None, to_datetime=None):
    return get_apiclient().services.partner.clients(
        partner_id=partner_id,
        from_datetime=from_datetime,
        to_datetime=to_datetime)


def code(code, partner_id=None):
    return get_apiclient().services.partner.code(code, partner_id=partner_id)


def orders(from_datetime=None, to_datetime=None, ids=None):
    return get_apiclient().services.partner.orders(
        from_datetime=from_datetime, to_datetime=to_datetime, ids=ids)


def partner(id, from_datetime=None, to_datetime=None):
    return get_apiclient().services.partner.partner(
        id, from_datetime=from_datetime, to_datetime=to_datetime)


def partners():
    return get_apiclient().services.partner.partners()
